/**
 * (c) 2002 Zyneo
 *
 * $Id: Receive.java,v 1.2 2003/03/19 16:14:18 nian Exp $
 *
 * <pre>
 *
 * $Log: Receive.java,v $
 * Revision 1.2  2003/03/19 16:14:18  nian
 * Corrected some comments
 *
 * Revision 1.1  2002/10/15 07:37:23  nian
 * Added file
 *
 *
 * </pre>
 */
package zyneo.sms.test.xml.tcp;

import org.apache.log4j.*;

import zyneo.sms.gateway.adaptor.xml.tcp.client.*;
import zyneo.sms.*;

import java.io.*;
import java.net.*;
import java.text.*;

/**
 * Simple application which receives SMS messages
 * and status reports by using the ReceiveConnection.
 * 
 * Usage: receive [port] [host]
 *
 * @author Niklas Andersson
 */
public class Receive
{
  public static final String DEFAULT_HOST = "localhost";
  public static final int DEFAULT_PORT = 3001;

  protected Category m_log;

  protected String m_host;
  protected int m_port;

  SimpleDateFormat m_sdf;

  /**
   * Constructor
   *
   * @param port
   * @param host
   */
  public Receive(int port,String host)
  {
    BasicConfigurator.configure();

    m_sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

    m_log = Category.getInstance(this.getClass());

    if(port < 1)
      m_port = DEFAULT_PORT;
    else
      m_port = port;

    if(host == null || "".equals(host) )
      m_host = DEFAULT_HOST;
    else
      m_host = host;
  }

  /**
   * Receives SMS-messages and status reports
   * until terminated.
   *
   */
  public void receive()
  {


    try
    {
      ReceiveConnection sc = new ReceiveConnection(m_host,m_port);
      while(true)
      {
      	m_log.info("Waiting for messages");
      	
        Object o = sc.receive();

        if(o instanceof zyneo.sms.Sms)
        {
          Sms s = (Sms)o;
          m_log.info("-==SMS-Start==-");
          m_log.info("From:" + s.getFrom());
          m_log.info("Message:" + s.getMessage());
          m_log.info("At:" + m_sdf.format(s.getTime()));
          m_log.info("-==SMS-End==-");
        }
        else
        {
          Notification n = (Notification)o;
          m_log.info("-==Notification-Start==-");

          m_log.info("ID:" + n.getId());
          m_log.info("Type:" + n.getType());
          if(n.getSMSCDate() != null)
            m_log.info("SMSC-Date:" + m_sdf.format(n.getSMSCDate()));

          if(n.getProviderDate() != null)
            m_log.info("Provider-Date:" + m_sdf.format(n.getProviderDate()));

          if(n.getDischargeDate() != null)
            m_log.info("Event-Date:" + m_sdf.format(n.getDischargeDate()));

          m_log.info("-==Notification-End==-");
        }
      }
    }
    catch(RequestException re)
    {
      m_log.error("Error receiving message",re);
    }
    catch(UnknownHostException uhe)
    {
      m_log.error("Error receiving message",uhe);
    }
    catch(IOException ioe)
    {
      m_log.error("Error receiving message",ioe);
    }
  }


  public static void main(String[] args)
  {
    Receive r = null;
    if(args.length == 0)
    {
      r = new Receive(-1,null);
      r.receive();
    }
    else if(args.length == 1)
    {
      r = new Receive(Integer.parseInt(args[0]),null);
      r.receive();
    }
    else if(args.length == 2)
    {
      r = new Receive(Integer.parseInt(args[0]),args[1]);
      r.receive();
    }
    else
      System.out.println("Usage: [port] [host]");
  }
}