from connection.SocketConnection import *
from protocol.send.SendRequest import *
from protocol.send.SendResponse import *
from base.Logger import *

class Client:

    """
        $Id: Client.py,v 1.1.1.1 2003/04/10 14:38:57 maro Exp $
        
        Used by GatewaySender for sending SMS messages.
        Validate the SMS message before sending it to the gateway,
        if errors are found a response is sent back and the message never
        reaches the gateway

        @author maro
    """

    m_conn = None
    m_log = None

    def __init__(self, host, port):
        self.m_log = Logger()
        self.m_conn = SocketConnection(host, port)

    def sendSMS(self, sms):
        """Validates the Sms message, if errors are found an appropriate
            error-response is sent back to the caller. If no errors are found
            the message is forwarded to the gateway"""
        if ( not sms.isValidMobile() ):
            return self.invalidMobile()

        if ( not sms.isValidText() ):
            return self.invalidText()

        request = SendRequest(sms)
        resp = self.m_conn.sendReceive(request.toXML())
        if ( resp ):
            response = SendResponse(resp)
            return response
        else:
            return resp

    def invalidMobile(self):
        """Creates a response with FAIL status, with appropriate error-code and
            message and returns it"""
        response = SendResponse()
        response.setStatus(response.STATUS_FAIL)
        response.setErrorCode(1)
        response.setResponseType("send")
        response.setErrorMessage("Invalid mobilephone number, use international format (+4670xxxxx/004670xxxx).")
        return response

    def invalidText(self):
        """Creates a response with FAIL status, with appropriate error-code and
            message and returns it"""
        response = SendResponse()
        response.setStatus(response.STATUS_FAIL)
        response.setErrorCode(2)
        response.setResponseType("send")
        response.setErrorMessage("Message length cannot exceed 160 character and must not be empty.")
        return response

