<?php
    
    //
    // Copyright (c) 2002-2003 Zyneo HB. (http://www.zyneo.com)
    // See LICENSE distributed with this package for more information.
    //

    include_once (_DOCROOT . "/base/Base.php");
    include_once (_DOCROOT . "/sdk/server/Server.php");
    include_once (_DOCROOT . "/sdk/protocol/receive/Response.php");

    /**
     * $Id: GatewayListener.php,v 1.1.1.1 2003/03/27 10:27:42 maro Exp $
     *
     * This class connects to the gateway and listens for incoming SMS and 
     * notifications.
     *
     * When an SMS message arrives the method 'onSMSReceive' is called with
     * the actual SMS object, which makes it possible to process the incoming
     * SMS however you want, save to db or whatever you like.
     *
     * When a notification arrives the method 'onNotificationReceive' is called
     * with the actual Notification object, which makes it possible to process
     * the notification as you like.
     * @package sdk
     * @author Magnus Rosenquist, Zyneo
     */    
    class GatewayListener
        extends Base
    {
    
        /** 
         * @global ClientSocket Connects to the gateway, also sends acknowledgements.
         */
        var $server;

        /**
         * Initializes the class
         */        
        function GatewayListener()
        {
            $this->registerClass(get_class($this));
        }
        
        /**
         * Starts the GatewayListener and listens for incoming SMS and
         * Notifications. Connects to the gateway by opening a socket to
         * '_LISTENER_HOST' and port '_LISTENER_PORT' found in 'config.inc'
         * @see config.inc
         */
        function run()
        {
            $this->registerMethod("run");
            $this->server = new Server();
            $this->server->addEventListener($this);
            $this->server->run();
        }
        
        /**
         * Called when an SMS is received. As specified in the XML/TCP adapter
         * documentation, an incoming SMS must be acknowledged. This is achieved
         * by creating a sdk.protocol.receive.Response object and send it
         * back to the gateway.
         * @param Sms $sms the received SMS message.
         * @see Response
         */
        function onSMSReceive($sms)
        {
            $this->registerMethod("onSMSReceive");
            $this->logInfo("We got an SMS!" );
            $this->logInfo("Message ......: " . $sms->getMessage());
            $this->logInfo("From .........: " . $sms->getFrom());
            $this->logInfo("To ...........: " . $sms->getTo());
            $this->logInfo("Received .....: " . $sms->getDelivered());
            //
            // Do some processing of the SMS here and when finished, acknowledge the
            // message by sending a Response back. 
            //
            $resp = new Response();
            $resp->setStatus("success");
            $this->server->sendResponse($resp);
        }
        
        /**
         * Called when a Notification is received. As specified in the XML/TCP adapter
         * documentation, an incoming Notification must be acknowledged. This is achieved
         * by creating a sdk.protocol.receive.Response object and send it
         * back to the gateway.
         * @param Notification $notification
         * @see Response
         */
        function onNotificationReceive($notification)
        {
            $this->registerMethod("onNotificationReceive");
            $this->logInfo("We got a notification!");
            $this->logInfo("Type .........: " . $notification->getNotificationType() . " [" . $notification->getNotificationTypeText(). "]");
            $this->logInfo("MessageId ....: " . $notification->getMessageId());
            $this->logInfo("Received .....: " . $notification->getProviderDate());
            //
            // Do some processing of the Notification here and when finished, acknowledge the
            // message by sending a Response back. 
            //
            $resp = new Response();
            $resp->setStatus("success");
            $this->server->sendResponse($resp);
        }
        
        
    }
?>
