<?php

    //
    // Copyright (c) 2002-2003 Zyneo HB. (http://www.zyneo.com)
    // See LICENSE distributed with this package for more information.
    //

    include_once(_DOCROOT . "/base/Base.php");
    
    /**
     * $Id: ServerSocket.php,v 1.1.1.1 2003/03/27 10:27:42 maro Exp $
     *
     * Provides a simple Socket object for use when listening on sockets.
     *
     * @package adapter.socket
     * @author Magnus Rosenquist, Zyneo
     */
    class ServerSocket
        extends Base
    {
        /** Host to connect to */
        var $__host = "";
        /** Port to connect to */
        var $__port = "";
        /** Listener object for callbacks */
        var $__listener;
        /** The listening socket */
        var $__socket;
        
        /**
         * Creates a new ServerSocket for use with specified host and port
         * @param string $host
         * @param int $port
         */
        function ServerSocket($host, $port)
        {
            $this->registerClass(get_class($this));
            $this->__host = $host;
            $this->__port = $port;  
        }

        /**
         * Adds the listener which is called when requests are received.
         * This is only used in GatewayListener.
         * @param object $listener the object listening for requests.
         * @see adapter.GatewaySender
         */
        function addMessageListener($listener)
        {
            $this->registerMethod("addMessageListener");
            $this->__listener = $listener;
        }

        /**
         * Listens on specified host and port for incoming requests from gateway.
         * Calls callback-method 'onMessageReceive' on the listener object when
         * message from socket is read.
         * @see $__listener
         */
        function listen()
        {
            $this->registerMethod("listen");
            set_time_limit(0);
            $this->logInfo("Connecting to: [".$this->__host .":" .$this->__port."]");
            $this->__socket = socket_create(AF_INET, SOCK_STREAM, 0)
                or die ("Could not create socket!\n\n");
            $result = socket_connect($this->__socket, $this->__host, $this->__port)
                or die ("Could not connect!\n\n");
            $this->logInfo("Connected and listening...");
            while ( true )
            {
                $input = socket_read($this->__socket, 1024)
                     or die ("Error!\n");
                if ( $input != "" )
                {
                   $this->logDebug("Got from socket: \n" . $input . "\n");
                   $this->__listener->onMessageReceive($input);
                }
            }
        }

        /**
         * Sends a message back to the gateway using the connected socket.
         * @param string $msg message to send.
         */        
        function send($msg)
        {
            $this->registerMethod("send");
            $this->logDebug("Sending message: \n" . $msg ."\n\n");
            socket_write($this->__socket, $msg, strlen($msg));
        }
        
    }
?>
